@@ -68,10 +68,10 @@ class TestHastexoJobs(TestCase):
             self.addCleanup(patcher.stop)
 
     def get_suspend_task_mock(self):
-        return self.mocks["SuspendStackTask"].return_value
+        return self.mocks["SuspendStackTask"]
 
     def get_delete_task_mock(self):
-        return self.mocks["DeleteStackTask"].return_value
+        return self.mocks["DeleteStackTask"]
 
     def test_dont_suspend_stack_with_no_provider(self):
         # Setup
